Skip to contents

DesignFixedCustom is intentionally not exported. Subclasses implement draw_assignments(r = 1) and return an n x r 0/1 assignment matrix. EDI handles subject storage, responses, and validation through DesignFixed.

Super classes

Design -> DesignFixed -> DesignFixedCustom

Methods

+ inherited public methods from DesignFixed
+ inherited public methods from Design


DesignFixedCustom$draw_assignments()

Draw assignments from the custom design.

Usage

DesignFixedCustom$draw_assignments(r = 1)

Arguments

r

Number of assignment vectors to draw.

Returns

An n x r matrix of 0/1 assignments.


DesignFixedCustom$clone()

The objects of this class are cloneable with this method.

Usage

DesignFixedCustom$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.