Skip to contents

Abstract class for Conditional Logistic Combined-Likelihood Combined Inference

Super classes

Inference -> InferenceAbstractKKCondLogitGLMM -> InferenceAbstractKKCondLogitGLMMOneLik

Methods

+ inherited public methods from InferenceAbstractKKCondLogitGLMM
+ inherited public methods from Inference


InferenceAbstractKKCondLogitGLMMOneLik$new()

Initialize KK combined incidence likelihood inference and set up the conditional-logit / marginal model components used by related InferenceAsympLik methods.

Usage

InferenceAbstractKKCondLogitGLMMOneLik$new(
  des_obj,
  model_formula = NULL,
  max_abs_reasonable_coef = 10000,
  max_abs_log_sigma = 8,
  max_abs_reasonable_se = 1.25,
  verbose = FALSE,
  smart_cold_start_default = NULL
)

Arguments

des_obj

A completed Design object with an incidence response.

model_formula

Optional formula for covariate adjustment.

max_abs_reasonable_coef

Cap for reasonable coefficient estimates.

max_abs_log_sigma

Cap for reasonable log random effect variance.

max_abs_reasonable_se

Cap for reasonable treatment standard errors.

verbose

Whether to print progress messages.

smart_cold_start_default

Whether to use smart cold start values.


InferenceAbstractKKCondLogitGLMMOneLik$clone()

The objects of this class are cloneable with this method.

Usage

InferenceAbstractKKCondLogitGLMMOneLik$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.