Skip to contents

Abstract class for all-subject marginal incidence inference in KK designs

Super class

Inference -> InferenceAbstractKKMarginalIncid

Methods

+ inherited public methods from Inference


InferenceAbstractKKMarginalIncid$new()

Initialize the shared KK marginal-incidence inference base, validate the binary matched/reservoir design, and prepare caches used by InferenceAbstractKKMarginalIncid.

Usage

InferenceAbstractKKMarginalIncid$new(
  des_obj,
  model_formula = NULL,
  verbose = FALSE,
  smart_cold_start_default = NULL
)

Arguments

des_obj

A completed Design object.

model_formula

Optional formula for covariate adjustment. If NULL (default), the formula from the design object is used and its pre-computed design matrix is reused. If a formula is provided, a new design matrix is constructed from the design's imputed covariates.

verbose

A flag indicating whether messages should be displayed.

smart_cold_start_default

Whether to use smart cold start values.


InferenceAbstractKKMarginalIncid$clone()

The objects of this class are cloneable with this method.

Usage

InferenceAbstractKKMarginalIncid$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.