Skip to contents

Abstract class for all-subject modified-Poisson inference in KK designs

Super classes

Inference -> InferenceAbstractKKMarginalIncid -> InferenceAbstractKKModifiedPoisson

Methods

+ inherited public methods from InferenceAbstractKKMarginalIncid
+ inherited public methods from Inference


InferenceAbstractKKModifiedPoisson$compute_estimate()

Compute the KK marginal incidence treatment-effect estimate using the class-specific marginal risk-difference or risk-ratio estimator and cache it for related InferenceAbstractKKMarginalIncid methods.

Usage

InferenceAbstractKKModifiedPoisson$compute_estimate(estimate_only = FALSE)

Arguments

estimate_only

Logical. If TRUE, skip variance component calculations.


InferenceAbstractKKModifiedPoisson$compute_estimate_with_bootstrap_weights()

Recomputes the KK marginal incidence estimate under Bayesian-bootstrap weights.

Usage

InferenceAbstractKKModifiedPoisson$compute_estimate_with_bootstrap_weights(
  subject_or_block_weights,
  estimate_only = FALSE
)

Arguments

subject_or_block_weights

Numeric vector. Row weights for bootstrap.

estimate_only

Logical. If TRUE, skip variance component calculations.


InferenceAbstractKKModifiedPoisson$compute_asymp_confidence_interval()

Compute the KK marginal incidence asymptotic confidence interval using the cached marginal effect and design-aware standard error. See InferenceAsymp.

Usage

InferenceAbstractKKModifiedPoisson$compute_asymp_confidence_interval(
  alpha = 0.05
)

Arguments

alpha

Numeric. Significance level (default 0.05).


InferenceAbstractKKModifiedPoisson$compute_asymp_two_sided_pval()

Compute the KK marginal incidence asymptotic two-sided p-value using the cached marginal effect and design-aware standard error. See InferenceAsymp.

Usage

InferenceAbstractKKModifiedPoisson$compute_asymp_two_sided_pval(delta = 0)

Arguments

delta

Numeric. Null treatment effect value (default 0).


InferenceAbstractKKModifiedPoisson$clone()

The objects of this class are cloneable with this method.

Usage

InferenceAbstractKKModifiedPoisson$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.