Skip to contents

Fits a variance-weighted compound estimator for KK matching-on-the-fly designs with continuous responses using robust regression for matched-pair differences and reservoir outcomes, with treatment and, optionally, all recorded covariates as predictors.

Super class

Inference -> InferenceContinKKRobustRegrIVWC

Methods

+ inherited public methods from Inference


InferenceContinKKRobustRegrIVWC$set_custom_randomization_statistic_function()

Usage

InferenceContinKKRobustRegrIVWC$set_custom_randomization_statistic_function(
  custom_randomization_statistic_function
)


InferenceContinKKRobustRegrIVWC$set_custom_randomization_statistic_cpp()

Usage

InferenceContinKKRobustRegrIVWC$set_custom_randomization_statistic_cpp(fn)


InferenceContinKKRobustRegrIVWC$approximate_randomization_distribution_beta_hat_T()

Usage

InferenceContinKKRobustRegrIVWC$approximate_randomization_distribution_beta_hat_T(
  r = 501,
  delta = 0,
  transform_responses = "none",
  show_progress = TRUE,
  permutations = NULL,
  debug = FALSE,
  zero_one_logit_clamp = .Machine$double.eps
)


InferenceContinKKRobustRegrIVWC$supports_rand_pval_for_incidence()

Usage

InferenceContinKKRobustRegrIVWC$supports_rand_pval_for_incidence()


InferenceContinKKRobustRegrIVWC$compute_rand_two_sided_pval()

Usage

InferenceContinKKRobustRegrIVWC$compute_rand_two_sided_pval(
  r = 501,
  delta = 0,
  transform_responses = "none",
  na.rm = TRUE,
  show_progress = TRUE,
  permutations = NULL,
  zero_one_logit_clamp = .Machine$double.eps
)


InferenceContinKKRobustRegrIVWC$clone()

The objects of this class are cloneable with this method.

Usage

InferenceContinKKRobustRegrIVWC$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.

Examples

# \donttest{
seq_des = DesignSeqOneByOneKK14$new(n = 10, response_type = 'continuous')
for (i in 1:10) {
  seq_des$add_one_subject_to_experiment_and_assign(data.frame(x1 = rnorm(1), x2 = rnorm(1)))
}
seq_des$add_all_subject_responses(rnorm(10))
inf = InferenceContinKKRobustRegrIVWC$new(seq_des)
inf$compute_estimate()
#> [1] 0.5861121
# }