Abstract class for delete-1 jackknife estimate correction and jackknife-Wald inference layered on top of bootstrap-capable inference classes.
Super classes
Inference -> InferenceRand -> InferenceRandCI -> InferenceNonParamBootstrap -> InferenceRandBootstrap -> InferenceRandBootstrapCI -> InferenceBayesianBootstrap -> InferenceJackknife
Methods
Public methods
+ inherited public methods from InferenceBayesianBootstrap
InferenceBayesianBootstrap$approximate_bayesian_bootstrap_distribution_beta_hat_T()InferenceBayesianBootstrap$compute_bayesian_bootstrap_confidence_interval()InferenceBayesianBootstrap$compute_bayesian_bootstrap_two_sided_pval()InferenceBayesianBootstrap$compute_estimate_with_bootstrap_weights()InferenceBayesianBootstrap$get_supported_bayesian_bootstrap_ci_types()InferenceBayesianBootstrap$get_supported_bayesian_bootstrap_pval_types()+ inherited public methods from InferenceRandBootstrapCI
+ inherited public methods from InferenceRandBootstrap
+ inherited public methods from InferenceNonParamBootstrap
InferenceNonParamBootstrap$approximate_bootstrap_distribution_beta_hat_T()InferenceNonParamBootstrap$approximate_m_out_of_n_bootstrap_distribution_beta_hat_T()InferenceNonParamBootstrap$approximate_subsampling_distribution_beta_hat_T()InferenceNonParamBootstrap$compute_bootstrap_confidence_interval()InferenceNonParamBootstrap$compute_bootstrap_two_sided_pval()InferenceNonParamBootstrap$compute_m_out_of_n_bootstrap_confidence_interval()InferenceNonParamBootstrap$compute_m_out_of_n_bootstrap_two_sided_pval()InferenceNonParamBootstrap$compute_subsampling_confidence_interval()InferenceNonParamBootstrap$compute_subsampling_sensitivity()InferenceNonParamBootstrap$compute_subsampling_two_sided_pval()InferenceNonParamBootstrap$get_supported_bootstrap_ci_types()InferenceNonParamBootstrap$get_supported_bootstrap_pval_types()InferenceNonParamBootstrap$select_optimal_b_subsampling()InferenceNonParamBootstrap$select_optimal_m_out_of_n_bootstrap()+ inherited public methods from InferenceRandCI
InferenceRandCI$compute_rand_confidence_interval()InferenceRandCI$compute_rand_two_sided_pval()+ inherited public methods from InferenceRand
+ inherited public methods from Inference
Inference$capabilities()Inference$compute_asymp_confidence_interval()Inference$compute_asymp_two_sided_pval()Inference$compute_estimate()Inference$compute_exact_confidence_interval()Inference$compute_exact_two_sided_pval_for_treatment_effect()Inference$duplicate()Inference$get_analysis_data()Inference$get_covariates()Inference$get_design_object()Inference$get_model_formula()Inference$get_nonestimable_reason()Inference$get_nonestimable_stage()Inference$get_optimization_alg()Inference$get_response()Inference$get_response_type()Inference$get_treatment()Inference$initialize()Inference$is_nonestimable()Inference$set_optimization_alg()Inference$set_seed()Inference$supports()
InferenceJackknife$approximate_jackknife_distribution_beta_hat_T()
Returns the leave-one-out jackknife estimate distribution.
InferenceJackknife$compute_jackknife_estimate()
Computes the delete-1 jackknife bias-corrected treatment estimate.
For blocking designs, this uses leave-one-block-out deletion units. For matching designs, it uses leave-match-out deletion units. For KK designs, it uses leave-match-out for matched pairs and leave-one-out for reservoir subjects.
InferenceJackknife$compute_jackknife_std_error()
Computes the delete-1 jackknife standard error.
For blocking designs, this uses leave-one-block-out deletion units. For matching designs, it uses leave-match-out deletion units. For KK designs, it uses leave-match-out for matched pairs and leave-one-out for reservoir subjects.
InferenceJackknife$compute_jackknife_wald_two_sided_pval()
Computes a two-sided Wald p-value using the jackknife estimate and jackknife standard error.
For blocking designs, this uses leave-one-block-out deletion units. For matching designs, it uses leave-match-out deletion units. For KK designs, it uses leave-match-out for matched pairs and leave-one-out for reservoir subjects.
InferenceJackknife$compute_jackknife_wald_confidence_interval()
Computes a normal-approximation confidence interval using the jackknife estimate and jackknife standard error.
For blocking designs, this uses leave-one-block-out deletion units. For matching designs, it uses leave-match-out deletion units. For KK designs, it uses leave-match-out for matched pairs and leave-one-out for reservoir subjects.