Skip to contents

Fits a multivariate Gehan-Wilcoxon rank regression for survival outcomes under a KK matching-on-the-fly design. The model adjusts for the treatment indicator and, optionally, all recorded covariates.

Details

Legacy class. Not fully tested in comprehensive_tests.R.

Super class

Inference -> InferenceSurvivalKKRankRegrIVWC

Methods

+ inherited public methods from Inference


InferenceSurvivalKKRankRegrIVWC$set_custom_randomization_statistic_function()

Usage

InferenceSurvivalKKRankRegrIVWC$set_custom_randomization_statistic_function(
  custom_randomization_statistic_function
)


InferenceSurvivalKKRankRegrIVWC$set_custom_randomization_statistic_cpp()

Usage

InferenceSurvivalKKRankRegrIVWC$set_custom_randomization_statistic_cpp(fn)


InferenceSurvivalKKRankRegrIVWC$approximate_randomization_distribution_beta_hat_T()

Usage

InferenceSurvivalKKRankRegrIVWC$approximate_randomization_distribution_beta_hat_T(
  r = 501,
  delta = 0,
  transform_responses = "none",
  show_progress = TRUE,
  permutations = NULL,
  debug = FALSE,
  zero_one_logit_clamp = .Machine$double.eps
)


InferenceSurvivalKKRankRegrIVWC$supports_rand_pval_for_incidence()

Usage

InferenceSurvivalKKRankRegrIVWC$supports_rand_pval_for_incidence()


InferenceSurvivalKKRankRegrIVWC$compute_rand_two_sided_pval()

Usage

InferenceSurvivalKKRankRegrIVWC$compute_rand_two_sided_pval(
  r = 501,
  delta = 0,
  transform_responses = "none",
  na.rm = TRUE,
  show_progress = TRUE,
  permutations = NULL,
  zero_one_logit_clamp = .Machine$double.eps
)


InferenceSurvivalKKRankRegrIVWC$clone()

The objects of this class are cloneable with this method.

Usage

InferenceSurvivalKKRankRegrIVWC$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.

Examples