Calculates the standard error of the difference in restricted mean survival times
Source:R/RcppExports.R
get_restricted_mean_se_diff.RdCalculates the standard error of the difference in restricted mean survival times

R/RcppExports.R
get_restricted_mean_se_diff.RdCalculates the standard error of the difference in restricted mean survival times