Skip to contents

This function stops any global fork or mirai clusters stored in the package environment and resets the core count to serial execution.

Usage

unset_num_cores()

Value

Invisible NULL.

Examples

set_num_cores(2)
unset_num_cores()