Abstract class for ordinal CLMM-based Inference in KK designs
Source:R/inference_ordinal_KK_clmm_abstract.R
InferenceAbstractKKOrdinalCLMM.RdAbstract class for ordinal CLMM-based Inference in KK designs
Super class
Inference -> InferenceAbstractKKOrdinalCLMM
Methods
Public methods
+ inherited public methods from Inference
Inference$capabilities()Inference$compute_exact_confidence_interval()Inference$compute_exact_two_sided_pval_for_treatment_effect()Inference$duplicate()Inference$get_analysis_data()Inference$get_covariates()Inference$get_design_object()Inference$get_model_formula()Inference$get_nonestimable_reason()Inference$get_nonestimable_stage()Inference$get_optimization_alg()Inference$get_response()Inference$get_response_type()Inference$get_treatment()Inference$is_nonestimable()Inference$set_optimization_alg()Inference$set_seed()Inference$supports()
InferenceAbstractKKOrdinalCLMM$new()
Initialize KK cumulative-link mixed-model inference for
ordinal responses, validate the matched design, and prepare the ordinal
likelihood used by InferenceAbstractKKOrdinalCLMM.
Usage
InferenceAbstractKKOrdinalCLMM$new(
des_obj,
model_formula = NULL,
use_rcpp = TRUE,
verbose = FALSE,
harden = TRUE,
smart_cold_start_default = NULL
)Arguments
des_objA completed
Designobject.model_formulaOptional formula for covariate adjustment.
use_rcppLogical. If
TRUE(default), use the internal Rcpp implementation (no external packages required). SetFALSEto fall back to ordinal::clmm.verboseA flag indicating whether messages should be displayed.
hardenWhether to apply robustness measures.
smart_cold_start_defaultWhether to use smart cold start values.
InferenceAbstractKKOrdinalCLMM$compute_estimate()
Compute the ordinal CLMM treatment-effect estimate by fitting
the cumulative-link mixed model and caching the treatment coefficient for
related InferenceAsymp methods.
InferenceAbstractKKOrdinalCLMM$compute_estimate_with_bootstrap_weights()
Recomputes the KK ordinal CLMM treatment estimate under Bayesian-bootstrap weights.
InferenceAbstractKKOrdinalCLMM$compute_asymp_confidence_interval()
Compute the ordinal CLMM asymptotic confidence interval for
the treatment coefficient using the fitted-model standard error. See
InferenceAsymp.
InferenceAbstractKKOrdinalCLMM$compute_asymp_two_sided_pval()
Compute the ordinal CLMM asymptotic two-sided p-value for the
treatment coefficient using the fitted-model standard error. See
InferenceAsymp.